@@ -1,7 +1,4 @@
 #include <Rcpp.h>
-using namespace Rcpp;
-
-// [[Rcpp::plugins(cpp11)]]
 
 #include "json.h"
 using json = nlohmann::json;
